==> ci-auto-update-phpboost-6.0.3.zip: phpboost_ynh/README_gl.md <==
<!--
NOTA: Este README foi creado automáticamente por <https://github.com/YunoHost/apps/tree/master/tools/readme_generator>
NON debe editarse manualmente.
-->

# PHPBoost para YunoHost

[![Nivel de integración](https://dash.yunohost.org/integration/phpboost.svg)](https://dash.yunohost.org/appci/app/phpboost) ![Estado de funcionamento](https://ci-apps.yunohost.org/ci/badges/phpboost.status.svg) ![Estado de mantemento](https://ci-apps.yunohost.org/ci/badges/phpboost.maintain.svg)

[![Instalar PHPBoost con YunoHost](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=phpboost)

*[Le este README en outros idiomas.](./ALL_README.md)*

> *Este paquete permíteche instalar PHPBoost de xeito rápido e doado nun servidor YunoHost.*  
> *Se non usas YunoHost, le a [documentación](https://yunohost.org/install) para saber como instalalo.*

## Vista xeral

PHPBoost allows everyone to create his own website without any particular knowledge required in webmastering.

**Versión proporcionada:** 6.0.3~ynh1

**Demo:** <https://demo.phpboost.com/>

## Capturas de pantalla

![Captura de pantalla de PHPBoost](./doc/screenshots/screenshot.png)

## Documentación e recursos

- Web oficial da app: <https://www.phpboost.com/>
- Documentación oficial para admin: <https://www.phpboost.com/wiki/wiki.php>
- Repositorio de orixe do código: <https://github.com/PHPBoost/PHPBoost>
- Tenda YunoHost: <https://apps.yunohost.org/app/phpboost>
- Informar dun problema: <https://github.com/YunoHost-Apps/phpboost_ynh/issues>

## Info de desenvolvemento

Envía a túa colaboración á [rama `testing`](https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing).

Para probar a rama `testing`, procede deste xeito:

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
ou
sudo yunohost app upgrade phpboost -u https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
```

**Máis info sobre o empaquetado da app:** <https://yunohost.org/packaging_apps>

==> ci-auto-update-phpboost-6.0.4.zip: phpboost_ynh/README_gl.md <==
<!--
NOTA: Este README foi creado automáticamente por <https://github.com/YunoHost/apps/tree/master/tools/readme_generator>
NON debe editarse manualmente.
-->

# PHPBoost para YunoHost

[![Nivel de integración](https://dash.yunohost.org/integration/phpboost.svg)](https://ci-apps.yunohost.org/ci/apps/phpboost/) ![Estado de funcionamento](https://ci-apps.yunohost.org/ci/badges/phpboost.status.svg) ![Estado de mantemento](https://ci-apps.yunohost.org/ci/badges/phpboost.maintain.svg)

[![Instalar PHPBoost con YunoHost](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=phpboost)

*[Le este README en outros idiomas.](./ALL_README.md)*

> *Este paquete permíteche instalar PHPBoost de xeito rápido e doado nun servidor YunoHost.*  
> *Se non usas YunoHost, le a [documentación](https://yunohost.org/install) para saber como instalalo.*

## Vista xeral

PHPBoost allows everyone to create his own website without any particular knowledge required in webmastering.

**Versión proporcionada:** phpboost-6.0.4~ynh1

**Demo:** <https://demo.phpboost.com/>

## Capturas de pantalla

![Captura de pantalla de PHPBoost](./doc/screenshots/screenshot.png)

## Documentación e recursos

- Web oficial da app: <https://www.phpboost.com/>
- Documentación oficial para admin: <https://www.phpboost.com/wiki/wiki.php>
- Repositorio de orixe do código: <https://github.com/PHPBoost/PHPBoost>
- Tenda YunoHost: <https://apps.yunohost.org/app/phpboost>
- Informar dun problema: <https://github.com/YunoHost-Apps/phpboost_ynh/issues>

## Info de desenvolvemento

Envía a túa colaboración á [rama `testing`](https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing).

Para probar a rama `testing`, procede deste xeito:

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
ou
sudo yunohost app upgrade phpboost -u https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
```

**Máis info sobre o empaquetado da app:** <https://yunohost.org/packaging_apps>
